## $Id: interfaces.py 8196 2012-04-17 12:14:03Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customized interfaces of the university application package.
"""

from zope import schema
from waeup.kofa.applicants.interfaces import (
    IApplicantBaseData,
    AppCatCertificateSource, CertificateSource)
from waeup.kofa.schoolgrades import ResultEntryField
from waeup.kofa.interfaces import SimpleKofaVocabulary
from waeup.kofa.schema import FormattedDate
from waeup.kofa.students.vocabularies import nats_vocab
from waeup.uniben.interfaces import (
    lgas_vocab, high_qual, high_grade, exam_types)
from waeup.uniben.interfaces import MessageFactory as _


class IUGApplicant(IApplicantBaseData):
    """An undergraduate applicant.

    """

    nationality = schema.Choice(
        source = nats_vocab,
        title = _(u'Nationality'),
        required = False,
        )
    lga = schema.Choice(
        source = lgas_vocab,
        title = _(u'State/LGA (Nigerians only)'),
        required = False,
        )

# This ordering doesn't work properly.
IUGApplicant[
    'nationality'].order =  IApplicantBaseData['sex'].order
IUGApplicant[
    'lga'].order =  IUGApplicant['nationality'].order


class IPGApplicant(IApplicantBaseData):
    """A postgraduate applicant.

    """

    nationality = schema.Choice(
        source = nats_vocab,
        title = _(u'Nationality'),
        required = False,
        )
    lga = schema.Choice(
        source = lgas_vocab,
        title = _(u'State/LGA (Nigerians only)'),
        required = False,
        )
    perm_address = schema.Text(
        title = _(u'Permanent Address'),
        required = False,
        )
    course1 = schema.Choice(
        title = _(u'1st Choice Course of Study'),
        source = AppCatCertificateSource(),
        required = True,
        )
    course2 = schema.Choice(
        title = _(u'2nd Choice Course of Study'),
        source = AppCatCertificateSource(),
        required = False,
        )
    hq_type = schema.Choice(
        title = _(u'Qualification Obtained'),
        required = False,
        readonly = False,
        vocabulary = high_qual,
        )
    hq_matric_no = schema.TextLine(
        title = _(u'Former Matric Number'),
        required = False,
        readonly = False,
        )
    hq_degree = schema.Choice(
        title = _(u'Class of Degree'),
        required = False,
        readonly = False,
        vocabulary = high_grade,
        )
    hq_school = schema.TextLine(
        title = _(u'Institution Attended'),
        required = False,
        readonly = False,
        )
    hq_session = schema.TextLine(
        title = _(u'Years Attended'),
        required = False,
        readonly = False,
        )
    hq_disc = schema.TextLine(
        title = _(u'Discipline'),
        required = False,
        readonly = False,
        )
    pp_school = schema.Choice(
        title = _(u'Qualification Obtained'),
        required = False,
        readonly = False,
        vocabulary = exam_types,
        )
    #presently = schema.Bool(
    #    title = _(u'Attending'),
    #    required = False,
    #    readonly = False,
    #    )
    presently_inst = schema.TextLine(
        title = _(u'If yes, name of institution'),
        required = False,
        readonly = False,
        )
    nysc_year = schema.Int(
        title = _(u'Nysc Year'),
        required = False,
        readonly = False,
        )
    nysc_lga = schema.Choice(
        source = lgas_vocab,
        title = _(u'Nysc Location'),
        required = False,
        )
    employer = schema.TextLine(
        title = _(u'Employer'),
        required = False,
        readonly = False,
        )
    emp_position = schema.TextLine(
        title = _(u'Employer Position'),
        required = False,
        readonly = False,
        )
    emp_start = FormattedDate(
        title = _(u'Start Date'),
        required = False,
        readonly = False,
        )
    emp_end = FormattedDate(
        title = _(u'End Date'),
        required = False,
        readonly = False,
        )
    emp_reason = schema.TextLine(
        title = _(u'Reason for Leaving'),
        required = False,
        readonly = False,
        )
    employer2 = schema.TextLine(
        title = _(u'2nd Employer'),
        required = False,
        readonly = False,
        )
    emp2_position = schema.TextLine(
        title = _(u'2nd Employer Position'),
        required = False,
        readonly = False,
        )
    emp2_start = FormattedDate(
        title = _(u'Start Date'),
        required = False,
        readonly = False,
        )
    emp2_end = FormattedDate(
        title = _(u'End Date'),
        required = False,
        readonly = False,
        )
    emp2_reason = schema.TextLine(
        title = _(u'Reason for Leaving'),
        required = False,
        readonly = False,
        )
    notice = schema.Text(
        title = _(u'Notice'),
        required = False,
        readonly = False,
        )
    screening_venue = schema.TextLine(
        title = _(u'Screening Venue'),
        required = False,
        readonly = False,
        )
    screening_score = schema.Int(
        title = _(u'Screening Score'),
        required = False,
        readonly = False,
        )
    course_admitted = schema.Choice(
        title = _(u'Admitted Course of Study'),
        source = CertificateSource(),
        required = False,
        readonly = False,
        )


# This ordering doesn't work properly.
IPGApplicant[
    'nationality'].order =  IApplicantBaseData['sex'].order
IPGApplicant[
    'lga'].order =  IPGApplicant['nationality'].order
IPGApplicant[
    'student_id'].order =  IPGApplicant['notice'].order


class ICustomApplicant(IUGApplicant,IPGApplicant):
    """An interface for both types of applicants.

    """

    def loggerInfo(ob_class, comment):
        """Adds an INFO message to the log file
        """

    def createStudent():
        """Create a student object from applicatnt data
        and copy applicant object.
        """

class IUGApplicantEdit(IUGApplicant):
    """An undergraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class IPGApplicantEdit(IPGApplicant):
    """A postgraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """
